# Flot Examples

The Cat's Eye Nebula (picture from Hubble).

With the image plugin, you can plot images. This is for example useful for getting ticks on complex prerendered visualizations. Instead of inputting data points, you put in the images and where their two opposite corners are supposed to be in plot space.

Images represent a little further complication because you need to make sure they are loaded before you can use them (Flot skips incomplete images). The plugin comes with a couple of helpers for doing that.